@@ -19,10 +19,9 @@
 
 # Set Oozie specific environment variables here.
 
-# Settings for the Embedded Tomcat that runs Oozie
+# Settings for the Embedded Jetty that runs Oozie
 # Java System properties for Oozie should be specified in this variable
 #
-export CATALINA_OPTS="$CATALINA_OPTS -Xmx1024m"
 
 # Oozie configuration file to load from Oozie configuration directory
 #
@@ -39,31 +38,3 @@ export CATALINA_OPTS="$CATALINA_OPTS -Xmx1024m"
 # Reload interval of the Log4J configuration file, in seconds
 #
 # export OOZIE_LOG4J_RELOAD=10
-
-# The port Oozie server runs
-#
-# export OOZIE_HTTP_PORT=11000
-
-# The port Oozie server runs if using SSL (HTTPS)
-#
-# export OOZIE_HTTPS_PORT=11443
-
-# The host name Oozie server runs on
-#
-# export OOZIE_HTTP_HOSTNAME=`hostname -f`
-
-# The base URL for callback URLs to Oozie
-#
-# export OOZIE_BASE_URL="http://${OOZIE_HTTP_HOSTNAME}:${OOZIE_HTTP_PORT}/oozie"
-
-# The location of the keystore for the Oozie server if using SSL (HTTPS)
-#
-# export OOZIE_HTTPS_KEYSTORE_FILE=${HOME}/.keystore
-
-# The password of the keystore for the Oozie server if using SSL (HTTPS)
-#
-# export OOZIE_HTTPS_KEYSTORE_PASS=password
-
-# The Oozie Instance ID
-#
-# export OOZIE_INSTANCE_ID="${OOZIE_HTTP_HOSTNAME}"
\ No newline at end of file
